@@ -1,10 +1,15 @@
 
 -- | Functions to load bitmap data from various places.
 module Graphics.Gloss.Data.Bitmap
-        ( BitmapData, BitmapFormat(..), RowOrder(..), PixelFormat(..)
+        ( Rectangle(..)
+        , BitmapData, bitmapSize
+        , BitmapFormat(..), RowOrder(..), PixelFormat(..)
         , bitmapOfForeignPtr
+        , bitmapDataOfForeignPtr
         , bitmapOfByteString
+        , bitmapDataOfByteString
         , bitmapOfBMP
+        , bitmapDataOfBMP
         , loadBMP)
 where
 import Graphics.Gloss.Rendering
